##  Overview
The SAP LeanIX for Confluence app lets you embed SAP LeanIX reports, diagrams, and fact sheets in your Confluence pages. This makes it easy to share knowledge about your enterprise architecture with stakeholders across your organization.
